@@ -5,7 +5,7 @@ pub fn throws(
     attribute_tokens: proc_macro::TokenStream,
     function_tokens: proc_macro::TokenStream,
 ) -> proc_macro::TokenStream {
-    ez_internal::proc_macros::throws(attribute_tokens.into(), function_tokens.into())
+    ez_impl::proc_macros::throws(attribute_tokens.into(), function_tokens.into())
         .unwrap_or_else(|err| {
             let err = format!("{err:?}");
             quote! { compile_error!(#err); }
@@ -18,7 +18,7 @@ pub fn try_throws(
     attribute_tokens: proc_macro::TokenStream,
     function_tokens: proc_macro::TokenStream,
 ) -> proc_macro::TokenStream {
-    ez_internal::proc_macros::try_throws(attribute_tokens.into(), function_tokens.into())
+    ez_impl::proc_macros::try_throws(attribute_tokens.into(), function_tokens.into())
         .unwrap_or_else(|err| {
             let err = format!("{err:?}");
             quote! { compile_error!(#err); }
@@ -31,7 +31,7 @@ pub fn main(
     attribute_tokens: proc_macro::TokenStream,
     function_tokens: proc_macro::TokenStream,
 ) -> proc_macro::TokenStream {
-    ez_internal::proc_macros::main(attribute_tokens.into(), function_tokens.into())
+    ez_impl::proc_macros::main(attribute_tokens.into(), function_tokens.into())
         .unwrap_or_else(|err| {
             let err = format!("{err:?}");
             quote! { compile_error!(#err); }
